/* #undef SDL2COMPAT_VENDOR_INFO */
#define SDL_REVISION_NUMBER 0

#ifdef SDL2COMPAT_VENDOR_INFO
#define SDL_REVISION "SDL-release-2.32.70-0-ga53b6ad (" SDL2COMPAT_VENDOR_INFO ")"
#else
#define SDL_REVISION "SDL-release-2.32.70-0-ga53b6ad"
#endif
